using System;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Collections.ObjectModel;
using System.Web.UI.HtmlControls;
using ZedGraph;
using System.Drawing;
using System.Web.UI.WebControls;
using System.Web.UI;

namespace CSSamples.Samples
{
    public partial class DisplayASimpleMap : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                ShapeFileFeatureLayer lineLayer = new ShapeFileFeatureLayer(MapPath("LineLayer.shp"));
                lineLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Canal1;
                lineLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                ShapeFileFeatureLayer pointLayer = new ShapeFileFeatureLayer(MapPath("PointLayer.shp"));
                pointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.DarkBlue, 6);
                pointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                InMemoryFeatureLayer recLayer = new InMemoryFeatureLayer();
                recLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(30, GeoColor.StandardColors.DarkBlue);
                recLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Map1.StaticOverlay.Layers.Add("line", lineLayer);
                Map1.StaticOverlay.Layers.Add("point", pointLayer);
                Map1.StaticOverlay.Layers.Add("rec", recLayer);
                Map1.StaticOverlay.TileType = TileType.SingleTile;

                lineLayer.Open();
                pointLayer.Open();
                RectangleShape extent = lineLayer.GetBoundingBox();
                extent.ExpandToInclude(pointLayer.GetBoundingBox());
                lineLayer.Close();
                pointLayer.Close();

                Map1.CurrentExtent = extent;
            }
        }

        protected void Map1_TrackShapeFinished(object sender, EventArgs e)
        {
            panel.Controls.Clear();
            if (Map1.EditOverlay.Features.Count != 0)
            {
                RectangleShape rectangle = Map1.EditOverlay.Features[0].GetBoundingBox();

                ShapeFileFeatureLayer lineLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers["line"];
                ShapeFileFeatureLayer pointLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers["point"];
                InMemoryFeatureLayer recLayer = (InMemoryFeatureLayer)Map1.StaticOverlay.Layers["rec"];

                lineLayer.Open();
                pointLayer.Open();
                recLayer.Open();
                Collection<Feature> lineFeatures = lineLayer.QueryTools.GetFeaturesIntersecting(rectangle, ReturningColumnsType.AllColumns);
                Collection<Feature> pointFeatures = pointLayer.QueryTools.GetFeaturesIntersecting(rectangle, ReturningColumnsType.AllColumns);
                recLayer.InternalFeatures.Clear();
                recLayer.InternalFeatures.Add(new Feature(rectangle));

                lineLayer.Close();
                pointLayer.Close();
                recLayer.Close();

                AddList(lineFeatures);
                AddList(pointFeatures);
            }

            Map1.EditOverlay.Features.Clear();
        }

        void AddList(Collection<Feature> features)
        {
            if (features.Count != 0)
            {
                WellKnownType featureType = features[0].GetWellKnownType();
                string shapeTypeString = (featureType == WellKnownType.Point ? "Points" : "Lines");

                System.Web.UI.WebControls.Label label = new System.Web.UI.WebControls.Label();
                label.Text = shapeTypeString + "<br/>";
                label.Font.Size = 10;
                panel.Controls.Add(label);
                foreach (Feature feature in features)
                {
                    LiteralControl br = new LiteralControl("<br/>");
                    HtmlAnchor anchor = new HtmlAnchor();
                    anchor.InnerHtml = feature.ColumnValues["Name"];
                    anchor.HRef = "#";
                    anchor.Attributes.Add("wkt", feature.GetWellKnownText());
                    anchor.Attributes.Add("onmouseover", "linkOver(this)");
                    anchor.Attributes.Add("onmouseout", "linkOut()");

                    panel.Controls.Add(anchor);
                    panel.Controls.Add(br);
                }
            }
        }
    }
}
